@@ -2,8 +2,9 @@ import re
 import os
 
 from bilili.tools import spider
+from bilili.utils.quality import quality_map
 from bilili.video import BililiContainer
-from bilili.common.base import repair_filename, touch_dir
+from bilili.utils.base import repair_filename, touch_dir, touch_url
 
 info_api = "https://api.bilibili.com/pgc/web/season/section?season_id={season_id}"
 parse_api = "https://api.bilibili.com/pgc/player/web/playurl?avid={avid}&cid={cid}&qn={qn}&ep_id={ep_id}"
@@ -86,6 +87,9 @@ def parse_segments(container, quality_sequence):
                 id=i+1,
                 url=segment["url"],
                 qn=qn,
+                height=quality_map[qn]['height'],
+                width=quality_map[qn]['width'],
+                size=segment["size"],
                 type="segment",
             )
     elif container.format == "m4s":
@@ -113,6 +117,9 @@ def parse_segments(container, quality_sequence):
                     id=1,
                     url=video['base_url'],
                     qn=qn,
+                    height=video['height'],
+                    width=video['width'],
+                    size=touch_url(video['base_url'], spider)[0],
                     type="video"
                 )
                 break
@@ -120,6 +127,9 @@ def parse_segments(container, quality_sequence):
             container.append_media(
                 id=2,
                 url=audio['base_url'],
+                height=None,
+                width=None,
+                size=touch_url(audio['base_url'], spider)[0],
                 qn=qn,
                 type="audio"
             )
