@@ -1,7 +1,8 @@
 import pytest
 
 from bilili.api.bangumi import get_title, get_context, get_containers, parse_segments
-from bilili.common.base import touch_dir
+from bilili.utils.base import touch_dir
+from bilili.utils.quality import quality_sequence_default
 from bilili.video import BililiContainer
 
 
@@ -39,4 +40,4 @@ def test_parse_segments(format):
         },
         format=format,
     )
-    parse_segments(container, [120, 116, 112, 80, 74, 64, 32, 16, 6])
+    parse_segments(container, quality_sequence_default)
